@@ -44,8 +44,8 @@ PushDialog::PushDialog (QWidget* parent ):
     QPushButton *okButton = m_buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
-    this->connect(m_buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
-    this->connect(m_buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+    this->connect(m_buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+    this->connect(m_buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
     m_buttonBox->button(QDialogButtonBox::Ok)->setDefault(true);
     okButton->setText(i18nc("@action:button", "Push"));
 
@@ -108,9 +108,9 @@ PushDialog::PushDialog (QWidget* parent ):
 
     //get branch names
     int currentBranchIndex;
-    QStringList branches = gitWrapper->branches(&currentBranchIndex);
+    const QStringList branches = gitWrapper->branches(&currentBranchIndex);
 
-    foreach (const QString& branch, branches) {
+    for (const QString& branch : branches) {
         if (branch.startsWith(QLatin1String("remotes/"))) {
             const QString remote = branch.section('/', 1, 1);
             const QString name = branch.section('/', 2);
