@@ -44,17 +44,19 @@
 #include <QIcon>
 #include <QMenu>
 #include <QDebug>
+
+#include <KApplicationTrader>
 #include <KMessageBox>
 #include <QFileDialog>
 #include <KConfig>
 #include <KConfigGroup>
 #include <KService>
-#include <KMimeTypeTrader>
 
 #include <KLocalizedString>
 #include <KPluginFactory>
 
 K_PLUGIN_FACTORY(FileViewHgPluginFactory, registerPlugin<FileViewHgPlugin>();)
+K_EXPORT_PLUGIN_VERSION(2)
 
 
 //TODO: Build a proper status signal system to sync HgWrapper/Dialogs with this
@@ -318,6 +320,17 @@ QString FileViewHgPlugin::fileName() const
     return QLatin1String(".hg");
 }
 
+QString FileViewHgPlugin::localRepositoryRoot(const QString& directory) const
+{
+    QProcess process;
+    process.setWorkingDirectory(directory);
+    process.start("hg", {"root"});
+    if (process.waitForReadyRead(100) && process.exitCode() == 0) {
+        return QString::fromUtf8(process.readAll().chopped(1));
+    }
+    return QString();
+}
+
 bool FileViewHgPlugin::beginRetrieval(const QString &directory)
 {
     clearMessages();
@@ -840,8 +853,8 @@ QString FileViewHgPlugin::visualDiffExecPath()
         return result;
     }
 
-    KService::List services = KMimeTypeTrader::self()->query("text/x-diff");
-    return services.first()->exec().split(' ').takeFirst();
+    KService::Ptr service = KApplicationTrader::preferredService(QStringLiteral("text/x-diff"));
+    return service ? service->exec().split(' ').takeFirst() : QString();
 }
 
 #include "fileviewhgplugin.moc"
