@@ -52,6 +52,7 @@
 #include "svncommands.h"
 
 K_PLUGIN_FACTORY(FileViewSvnPluginFactory, registerPlugin<FileViewSvnPlugin>();)
+K_EXPORT_PLUGIN_VERSION(2)
 
 FileViewSvnPlugin::FileViewSvnPlugin(QObject* parent, const QList<QVariant>& args) :
     KVersionControlPlugin(parent),
@@ -152,6 +153,17 @@ QString FileViewSvnPlugin::fileName() const
     return QLatin1String(".svn");
 }
 
+QString FileViewSvnPlugin::localRepositoryRoot(const QString& directory) const
+{
+    QProcess process;
+    process.setWorkingDirectory(directory);
+    process.start("svn", {"info", "--show-item", "wc-root"});
+    if (process.waitForReadyRead(100) && process.exitCode() == 0) {
+        return QString::fromUtf8(process.readAll().chopped(1));
+    }
+    return QString();
+}
+
 bool FileViewSvnPlugin::beginRetrieval(const QString& directory)
 {
     Q_ASSERT(directory.endsWith(QLatin1Char('/')));
